<?php

namespace App\Http\Controllers\Admin;

use App\Model\admin\AdminUser;
use App\Model\admin\SettingModel;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Input;

use Illuminate\Support\Facades\Redirect;
use \View;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class AdminController extends Controller
{

    protected function validator(array $data)
    {
        return Validator::make($data, [
            'username' => 'required|string|max:255',
            'password' => 'required|string|min:6|confirmed',
        ]);
    }

    //登录页面
    public function loginAction(Request $request ){

       if($request->isMethod('post')){

            if (Auth::attempt(['username'=>Input::get("username"),'password'=>Input::get("password")],false)){
                return Redirect::to("admin-dashboard")->with("message","登录成功");

            }else{
                return Redirect::to("admin-login")->with("message","用户名密码不正确")->withInput();
            }
        }
        if (Auth::check()){ //已经登录
            return Redirect::to("admin-dashboard");
        }

        return View::make("admin.login");
    }

    public  function logoutAction(){
        Auth::logout();
        return Redirect::to("admin-login")->with("messge","退出成功！");
    }

    public function dashboardAction(){
       if ( !Auth::check()){
          return Redirect::to("admin-login");
       }
        return View::make("admin.dashboard",['username'=>Auth::user()->nickname]);
    }

    public  function managerAction(){
        $admin = AdminUser::get();
        //dd($admin);
        return View::make("admin.manager",['list'=>$admin]);
    }

    public function  addAction(Request $request){

        if($request->isMethod('post')){

            $validate  = \Validator::make($request->input(),[
                'username'=>"required",
                'password'=>"required"
            ],[
                'required'=>":attribute必填项不能为空",
            ],[
                'username'=>'用户名',
                'password'=>'密码'
            ]);

            if($validate->fails()){
                return \redirect()->back()->withErrors($validate)->withInput();
            }

            $admin = new AdminUser();
            $admin->username = Input::get('username');
            $admin->password = \Hash::make(Input::get('password'));
            $admin->nickname = Input::get('nickname')?:Input::get("username");
            $admin->logtime = time();
            if($admin->save()){
                return Redirect::to('admin-list')->with('message','操作成功！');
            }else{
                return \redirect()->back()->with('message','添加失败！');
            }

        }
        return View::make('admin.managerform');
    }

    public  function updateAction(Request $request,$id){
        $admin = AdminUser::find($id);

        if($request->isMethod('post')){

            $validate  = \Validator::make($request->input(),[
                'username'=>"required",

            ],[
                'required'=>":attribute必填项不能为空",
            ],[
                'username'=>'用户名',

            ]);

            if($validate->fails()){
                return \redirect()->back()->withErrors($validate)->withInput();
            }

            $admin->username = Input::get('username');
            $password = \Hash::make(Input::get('password'));
            $admin->password = empty($password)  ?$admin->password :$password;
            $admin->nickname = Input::get('nickname')?:Input::get("username");
            $admin->logtime = time();
            if($admin->save()){
                return Redirect::to('admin-list')->with('message','操作成功！');
            }else{
                return \redirect()->back()->with('message','添加失败！');
            }
        }

        return View::make("admin.managerform",['infos'=>$admin]);
    }

    public  function  settingsAction(Request $request){
        if($request->isMethod('post')){
            $data = [];
            foreach ($request->input('settings') as $key=>$value){
                $data[] = ['skey'=>$key,'svalue'=>$value];
            }
            DB::table('settings')->truncate();
           if( DB::table('settings')->insert($data)){
                return Redirect::refresh()->with('message','操作成功');
           }else{
               return \redirect()->back()->with('message','添加失败');
           }
        }
       $list =  [];
        foreach (   DB::table('settings')->get() as $item ){

            $list[$item->skey] = $item->svalue;
        }
        return View::make("admin.settingsform",['settings'=>$list]);
    }
}
